@@ -42,19 +42,6 @@ struct _EogListStorePrivate {
 	GMutex *mutex;            /* Mutex for saving the jobs in the model */
 };
 
-static void
-eog_list_store_finalize (GObject *object)
-{
-	EogListStore *store = EOG_LIST_STORE (object);
-
-	if (store->priv != NULL) {
-		g_free (store->priv);
-		store->priv = NULL;
-	}
-
-	G_OBJECT_CLASS (eog_list_store_parent_class)->finalize (object);
-}
-
 static void
 foreach_monitors_free (gpointer data, gpointer user_data)
 {
@@ -93,7 +80,6 @@ eog_list_store_class_init (EogListStoreClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->finalize = eog_list_store_finalize;
 	object_class->dispose = eog_list_store_dispose;
 
 	g_type_class_add_private (object_class, sizeof (EogListStorePrivate));
@@ -121,8 +107,8 @@ eog_list_store_compare_func (GtkTreeModel *model,
 			    EOG_LIST_STORE_EOG_IMAGE, &image_b,
 			    -1);
 
-	r_value = strcasecmp (eog_image_get_collate_key (image_a),
-			      eog_image_get_collate_key (image_b));
+	r_value = strcmp (eog_image_get_collate_key (image_a),
+			  eog_image_get_collate_key (image_b));
 
 	g_object_unref (G_OBJECT (image_a));
 	g_object_unref (G_OBJECT (image_b));
@@ -345,8 +331,7 @@ eog_list_store_remove (EogListStore *store, GtkTreeIter *iter)
  * @image: An #EogImage.
  *
  * Adds an #EogImage to @store. The thumbnail of the image is not
- * loaded and will only be loaded if the thumbnail is made visible
- * or eog_list_store_set_thumbnail() is called.
+ * loaded and will only be loaded if the thumbnail is made visible.
  *
  **/
 void
@@ -389,6 +374,7 @@ file_monitor_changed_cb (GFileMonitor *monitor,
 	const char *mimetype;
 	GFileInfo *file_info;
 	GtkTreeIter iter;
+	EogImage *image;
 
 	switch (event) {
 	case G_FILE_MONITOR_EVENT_CHANGED:
@@ -402,6 +388,11 @@ file_monitor_changed_cb (GFileMonitor *monitor,
 
 		if (is_file_in_list_store_file (store, file, &iter)) {
 			if (eog_image_is_supported_mime_type (mimetype)) {
+				gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+						    EOG_LIST_STORE_EOG_IMAGE, &image,
+						    -1);
+				eog_image_file_changed (image);
+				g_object_unref (image);
 				eog_list_store_thumbnail_refresh (store, &iter);
 			} else {
 				eog_list_store_remove (store, &iter);
@@ -457,6 +448,7 @@ file_monitor_changed_cb (GFileMonitor *monitor,
 	case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
 	case G_FILE_MONITOR_EVENT_PRE_UNMOUNT:
 	case G_FILE_MONITOR_EVENT_UNMOUNTED:
+	case G_FILE_MONITOR_EVENT_MOVED:
 		break;
 	}
 }
@@ -720,7 +712,7 @@ eog_list_store_get_pos_by_image (EogListStore *store, EogImage *image)
  * Gets the #EogImage in the position @pos of @store. If there is
  * no image at position @pos, %NULL is returned.
  *
- * Returns: the #EogImage in position @pos or %NULL.
+ * Returns: (transfer full): the #EogImage in position @pos or %NULL.
  *
  **/
 EogImage *
