@@ -30,6 +30,9 @@
 #include <dbus/dbus-glib-bindings.h>
 #include <gdk/gdkx.h>
 #endif
+#ifdef HAVE_INTROSPECTION
+#include <girepository.h>
+#endif
 
 #include "eog-session.h"
 #include "eog-debug.h"
@@ -51,7 +54,7 @@ static EogStartupFlags flags;
 
 static gboolean fullscreen = FALSE;
 static gboolean slide_show = FALSE;
-static gboolean disable_collection = FALSE;
+static gboolean disable_gallery = FALSE;
 #if HAVE_DBUS
 static gboolean force_new_instance = FALSE;
 #endif
@@ -71,7 +74,7 @@ _print_version_and_exit (const gchar *option_name,
 static const GOptionEntry goption_options[] =
 {
 	{ "fullscreen", 'f', 0, G_OPTION_ARG_NONE, &fullscreen, N_("Open in fullscreen mode"), NULL  },
-	{ "disable-image-collection", 'c', 0, G_OPTION_ARG_NONE, &disable_collection, N_("Disable image collection"), NULL  },
+	{ "disable-gallery", 'g', 0, G_OPTION_ARG_NONE, &disable_gallery, N_("Disable image gallery"), NULL  },
 	{ "slide-show", 's', 0, G_OPTION_ARG_NONE, &slide_show, N_("Open in slideshow mode"), NULL  },
 #if HAVE_DBUS
 	{ "new-instance", 'n', 0, G_OPTION_ARG_NONE, &force_new_instance, N_("Start a new instance instead of reusing an existing one"), NULL },
@@ -88,8 +91,8 @@ set_startup_flags (void)
   if (fullscreen)
     flags |= EOG_STARTUP_FULLSCREEN;
 
-  if (disable_collection)
-    flags |= EOG_STARTUP_DISABLE_COLLECTION;
+  if (disable_gallery)
+    flags |= EOG_STARTUP_DISABLE_GALLERY;
 
   if (slide_show)
     flags |= EOG_STARTUP_SLIDE_SHOW;
@@ -184,6 +187,7 @@ main (int argc, char **argv)
 {
 	GError *error = NULL;
 	GOptionContext *ctx;
+	GtkSettings *settings;
 
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
@@ -199,6 +203,9 @@ main (int argc, char **argv)
 	/* Option groups are free'd together with the context 
 	 * Using gtk_get_option_group here initializes gtk during parsing */
 	g_option_context_add_group (ctx, gtk_get_option_group (TRUE));
+#ifdef HAVE_INTROSPECTION
+	g_option_context_add_group (ctx, g_irepository_get_option_group ());
+#endif
 
 	if (!g_option_context_parse (ctx, &argc, &argv, &error)) {
 		gchar *help_msg;
@@ -238,7 +245,6 @@ main (int argc, char **argv)
 	eog_job_queue_init ();
 	gdk_threads_init ();
 	eog_thumbnail_init ();
-	eog_plugin_engine_init ();
 
 	/* Add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
@@ -247,6 +253,11 @@ main (int argc, char **argv)
 	gtk_window_set_default_icon_name ("eog");
 	g_set_application_name (_("Eye of GNOME Image Viewer"));
 
+	settings = gtk_settings_get_default ();
+	g_object_set (G_OBJECT (settings),
+	              "gtk-application-prefer-dark-theme", TRUE,
+	              NULL);
+
 	load_files ();
 
 	gdk_threads_enter ();
@@ -258,8 +269,6 @@ main (int argc, char **argv)
   	if (startup_files)
 		g_strfreev (startup_files);
 
-	eog_plugin_engine_shutdown ();
-
 #ifdef HAVE_RSVG
 	rsvg_term();
 #endif
